@@ -10,6 +10,7 @@ use {
 #[derive(Accounts)]
 #[instruction(
     namespace: String,
+    is_serial: bool,
     bump: u8,
 )]
 pub struct CreateIndex<'info> {
@@ -19,7 +20,7 @@ pub struct CreateIndex<'info> {
             state::SEED_INDEX, 
             signer.key().as_ref(), 
             namespace.as_ref()
-        ], 
+        ],
         bump = bump, 
         payer = signer, 
         space = 8 + size_of::<state::Index>()
@@ -36,6 +37,7 @@ pub struct CreateIndex<'info> {
 pub fn handler(
     ctx: Context<CreateIndex>, 
     namespace: String,
+    is_serial: bool,
     bump: u8,
 ) -> ProgramResult {
     // Get accounts.
@@ -43,9 +45,10 @@ pub fn handler(
     let signer = &ctx.accounts.signer;
 
     // Initialize index account.
-    index.namespace = namespace;
     index.owner = signer.key();
-    index.item_count = 0;
+    index.namespace = namespace;
+    index.count = 0;
+    index.is_serial = is_serial;
     index.bump = bump;
     
     return Ok(());
